@@ -4,7 +4,6 @@
 #'     DO NOT REMOVE.
 #' @import shiny
 #' @import bslib
-#' @import shinydashboard
 #' @noRd
 app_ui <- function(request) {
   tagList(
@@ -14,18 +13,8 @@ app_ui <- function(request) {
     bslib::page_navbar(
       title = "ordinalsimr",
       fillable = c("Simulation Inputs"),
-      theme = bslib::bs_theme(
-        version = 5,
-        bootswatch = "materia",
-        primary = "#337ab7",
-        secondary = "#c7dced",
-        success = "#4caf50",
-        info = "#2196f3",
-        warning = "#ff9800",
-        danger = "#f44336",
-        light = "#f5f5f5",
-        dark = "#263238"
-      ),
+      theme = bs_theme(5, "flatly"),
+      navbar_options = navbar_options(class = "bg-primary", theme = "dark"),
       mod_homepage_ui("homepage_1"),
       mod_simulation_inputs_page_ui("simulation_inputs_page_1"),
       mod_distributions_page_ui("distributions_page_1"),
